@@ -1,5 +1,5 @@
 //
-// Copyright (c) 2019-2022 Red Hat, Inc.
+// Copyright (c) 2019-2023 Red Hat, Inc.
 // This program and the accompanying materials are made
 // available under the terms of the Eclipse Public License 2.0
 // which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -63,7 +63,7 @@ func (d *DevWorkspaceConfigReconciler) Reconcile(ctx *chetypes.DeployContext) (r
 		dwoc.Config = &controllerv1alpha1.OperatorConfiguration{}
 	}
 
-	if err := updateWorkspaceConfig(ctx.CheCluster, dwoc.Config); err != nil {
+	if err := updateWorkspaceConfig(ctx, dwoc.Config); err != nil {
 		return reconcile.Result{}, false, err
 	}
 
@@ -78,7 +78,8 @@ func (d *DevWorkspaceConfigReconciler) Finalize(ctx *chetypes.DeployContext) boo
 	return true
 }
 
-func updateWorkspaceConfig(cheCluster *chev2.CheCluster, operatorConfig *controllerv1alpha1.OperatorConfiguration) error {
+func updateWorkspaceConfig(ctx *chetypes.DeployContext, operatorConfig *controllerv1alpha1.OperatorConfiguration) error {
+	cheCluster := ctx.CheCluster
 	devEnvironments := &cheCluster.Spec.DevEnvironments
 	if operatorConfig.Workspace == nil {
 		operatorConfig.Workspace = &controllerv1alpha1.WorkspaceConfig{}
@@ -104,6 +105,17 @@ func updateWorkspaceConfig(cheCluster *chev2.CheCluster, operatorConfig *control
 
 	updateWorkspaceImagePullPolicy(devEnvironments.ImagePullPolicy, operatorConfig.Workspace)
 
+	// If the CheCluster has a configured proxy, or if the Che Operator has detected a proxy configuration,
+	// we need to disable automatic proxy handling in the DevWorkspace Operator as its implementation collides
+	// with ours -- they set environment variables the deployment spec explicitly, which overrides the proxy-settings
+	// automount configmap.
+	if ctx.Proxy.HttpProxy != "" || ctx.Proxy.HttpsProxy != "" {
+		if operatorConfig.Routing == nil {
+			operatorConfig.Routing = &controllerv1alpha1.RoutingConfig{}
+		}
+		disableDWOProxy(operatorConfig.Routing)
+	}
+
 	operatorConfig.Workspace.DeploymentStrategy = v1.DeploymentStrategyType(utils.GetValue(string(devEnvironments.DeploymentStrategy), constants.DefaultDeploymentStrategy))
 	return nil
 }
@@ -213,6 +225,16 @@ func updateProjectCloneConfig(devEnvironments *chev2.CheClusterDevEnvironments,
 	workspaceConfig.ProjectCloneConfig.Resources = cheResourcesToCoreV1Resources(container.Resources)
 }
 
+func disableDWOProxy(routingConfig *controllerv1alpha1.RoutingConfig) {
+	// Since we create proxy configmaps to mount proxy settings, we want to disable
+	// proxy handling in DWO; otherwise the env vars added by DWO will override the env
+	// vars we intend to mount via configmap.
+	routingConfig.ProxyConfig = &controllerv1alpha1.Proxy{}
+	routingConfig.ProxyConfig.HttpProxy = pointer.String("")
+	routingConfig.ProxyConfig.HttpsProxy = pointer.String("")
+	routingConfig.ProxyConfig.NoProxy = pointer.String("")
+}
+
 // Returns the default container security context required for container builds.
 // Returns an error if the default container security context could not be retrieved.
 func getDefaultContainerSecurityContext() (*corev1.SecurityContext, error) {
